==> pyauxlib-0.8.1.tar.gz: pyauxlib-0.8.1/README.md <==
# PyAuxLib

----

| | |
| --- | --- |
| **Docs** | [![Documentation Status](<https://readthedocs.org/projects/pyauxlib/badge/?version=latest> 'Documentation Status')](<https://pyauxlib.readthedocs.io/en/latest/>) |
| **Package** | [![PyPI - Version](<https://img.shields.io/pypi/v/pyauxlib.svg?logo=pypi&label=PyPI&logoColor=gold>)](<https://pypi.python.org/pypi/pyauxlib>) [![PyPI - Downloads](<https://img.shields.io/pypi/dm/pyauxlib.svg?color=blue&label=Downloads&logo=pypi&logoColor=gold>)](<https://pypi.python.org/pypi/pyauxlib>) [![PyPI - Python Version](<https://img.shields.io/pypi/pyversions/pyauxlib.svg?logo=python&label=Python&logoColor=gold>)](<https://pypi.python.org/pypi/pyauxlib>) |
| **CI/CD** | [![CI - Test](<https://github.com/psolsfer/pyauxlib/actions/workflows/test-push-pr.yml/badge.svg>)](<https://github.com/psolsfer/pyauxlib/actions/workflows/test-push-pr.yml>) [![CD - Build](<https://github.com/psolsfer/pyauxlib/actions/workflows/python-publish.yml/badge.svg>)](<https://github.com/psolsfer/pyauxlib/actions/workflows/python-publish.yml>) |
| **GitHub** |  [![PyAuxLib](https://img.shields.io/badge/GitHub-pyauxlib-blue.svg)](<https://github.com/psolsfer/pyauxlib>) [![Forks](https://img.shields.io/github/forks/psolsfer/pyauxlib.svg)](<https://github.com/psolsfer/pyauxlib>) [![Stars](https://img.shields.io/github/stars/psolsfer/pyauxlib.svg)](<https://github.com/psolsfer/pyauxlib>) [![Issues](https://img.shields.io/github/issues/psolsfer/pyauxlib.svg)](<https://github.com/psolsfer/pyauxlib>) |
| **Code style** | [![linting - Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) [![code style - Ruff formatter](https://img.shields.io/badge/Ruff%20Formatter-checked-blue.svg)](https://github.com/astral-sh/ruff) [![types - Mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/) |
| **License** | [![License - BSD-3-Clause](<https://img.shields.io/pypi/l/pyauxlib.svg>)](<https://spdx.org/licenses/BSD-3-Clause.html>) |

Python library designed to provide auxiliary functionalities that can enhance your Python project.

## Features

TODO

## Credits

This package was created with [Cookiecutter] / [Cruft] and the [Cookiecutter PyPackage Poet] project template.

[Cookiecutter]: https://github.com/audreyr/cookiecutter
[Cruft]: https://github.com/cruft/cruft
[Cookiecutter PyPackage Poet]: https://github.com/psolsfer/cookiecutter-pypackage-poet

==> pyauxlib-0.12.4.tar.gz: pyauxlib-0.12.4/README.md <==
# pyauxlib

----

| | |
| --- | --- |
| **Docs** | [![Documentation Status](<https://readthedocs.org/projects/pyauxlib/badge/?version=stable> 'Documentation Status')](<https://pyauxlib.readthedocs.io/en/stable/>) |
| **Package** | [![PyPI - Version](<https://img.shields.io/pypi/v/pyauxlib.svg?logo=pypi&label=PyPI&logoColor=gold>)](<https://pypi.python.org/pypi/pyauxlib>) [![PyPI - Downloads](<https://img.shields.io/pypi/dm/pyauxlib.svg?color=blue&label=Downloads&logo=pypi&logoColor=gold>)](<https://pypi.python.org/pypi/pyauxlib>) [![PyPI - Python Version](<https://img.shields.io/pypi/pyversions/pyauxlib.svg?logo=python&label=Python&logoColor=gold>)](<https://pypi.python.org/pypi/pyauxlib>) |
| **CI/CD** | [![CI - Test](<https://github.com/psolsfer/pyauxlib/actions/workflows/test-push-pr.yml/badge.svg>)](<https://github.com/psolsfer/pyauxlib/actions/workflows/test-push-pr.yml>) [![CD - Build](<https://github.com/psolsfer/pyauxlib/actions/workflows/python-publish.yml/badge.svg>)](<https://github.com/psolsfer/pyauxlib/actions/workflows/python-publish.yml>) |
| **GitHub** |  [![pyauxlib](https://img.shields.io/badge/GitHub-pyauxlib-blue.svg)](<https://github.com/psolsfer/pyauxlib>) [![Forks](https://img.shields.io/github/forks/psolsfer/pyauxlib.svg)](<https://github.com/psolsfer/pyauxlib>) [![Stars](https://img.shields.io/github/stars/psolsfer/pyauxlib.svg)](<https://github.com/psolsfer/pyauxlib>) [![Issues](https://img.shields.io/github/issues/psolsfer/pyauxlib.svg)](<https://github.com/psolsfer/pyauxlib>) |
| **Code style** | [![linting - Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) [![code style - Ruff formatter](https://img.shields.io/badge/Ruff%20Formatter-checked-blue.svg)](https://github.com/astral-sh/ruff) [![types - Mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/) |
| **License** | [![License - BSD-3-Clause](<https://img.shields.io/pypi/l/pyauxlib.svg>)](<https://spdx.org/licenses/BSD-3-Clause.html>) |

Auxiliary library for python.

## Features

TODO

## Credits

This package was created with [Cookiecutter] / [Cruft] and the [Cookiecutter PyPackage uv] project template.

[Cookiecutter]: https://github.com/audreyr/cookiecutter
[Cruft]: https://github.com/cruft/cruft
[Cookiecutter PyPackage uv]: https://github.com/psolsfer/cookiecutter-pypackage-uv
